@@ -167,7 +167,7 @@ class uclassify:
             textbase64 = doc.createElement("textBase64")
             traintag = doc.createElement("train")
             textbase64.setAttribute("id",className + "Text" + str(counter))
-            ptext = doc.createTextNode(str(text))
+            ptext = doc.createTextNode(text.decode("utf-8"))
             textbase64.appendChild(ptext)
             textstag.appendChild(textbase64)
             traintag.setAttribute("id","Train"+className+ str(counter))
@@ -207,7 +207,7 @@ class uclassify:
             textbase64 = doc.createElement("textBase64")
             traintag = doc.createElement("untrain")
             textbase64.setAttribute("id",className + "Text" + str(counter))
-            ptext = doc.createTextNode(str(text))
+            ptext = doc.createTextNode(text.decode("utf-8"))
             textbase64.appendChild(ptext)
             textstag.appendChild(textbase64)
             traintag.setAttribute("id","Untrain"+className+ str(counter))
@@ -246,7 +246,7 @@ class uclassify:
             textbase64 = doc.createElement("textBase64")
             classifytag = doc.createElement("classify")
             textbase64.setAttribute("id","Classifytext"+ str(counter))
-            ptext = doc.createTextNode(str(text))
+            ptext = doc.createTextNode(text.decode("utf-8"))
             textbase64.appendChild(ptext)
             classifytag.setAttribute("id","Classify"+ str(counter))
             classifytag.setAttribute("classifierName",classifierName)
@@ -311,7 +311,7 @@ class uclassify:
             textbase64 = doc.createElement("textBase64")
             classifytag = doc.createElement("classifyKeywords")
             textbase64.setAttribute("id","Classifytext"+ str(counter))
-            ptext = doc.createTextNode(str(text))
+            ptext = doc.createTextNode(text.decode("utf-8"))
             textbase64.appendChild(ptext)
             classifytag.setAttribute("id","Classify"+ str(counter))
             classifytag.setAttribute("classifierName",classifierName)
